Index: code/branches/resource2/src/core/Core.h
===================================================================
--- code/branches/resource2/src/core/Core.h	(revision 5641)
+++ code/branches/resource2/src/core/Core.h	(revision 5645)
@@ -57,5 +57,5 @@
         The Core class is a singleton used to configure the program basics.
     @details
-        The class provides information about the media, config and log path.
+        The class provides information about the data, config and log path.
         It determines those by the use of platform specific functions.
     @remark
@@ -91,19 +91,19 @@
             static void  resetLanguage();
 
-            static void tsetExternalMediaPath(const std::string& path);
+            static void tsetExternalDataPath(const std::string& path);
             //! Returns the path to the data files as boost::filesystem::path
-            static const boost::filesystem::path& getMediaPath();
+            static const boost::filesystem::path& getDataPath();
             //! Returns the path to the external data files as boost::filesystem::path
-            static const boost::filesystem::path& getExternalMediaPath();
+            static const boost::filesystem::path& getExternalDataPath();
             //! Returns the path to the config files as boost::filesystem::path
             static const boost::filesystem::path& getConfigPath();
             //! Returns the path to the log files as boost::filesystem::path
             static const boost::filesystem::path& getLogPath();
-            //! Returns the path to the data files as std::string
             //! Returns the path to the root folder as boost::filesystem::path
             static const boost::filesystem::path& getRootPath();
-            static std::string getMediaPathString();
+            //! Returns the path to the data files as std::string
+            static std::string getDataPathString();
             //! Returns the path to the external data files as std::string
-            static std::string getExternalMediaPathString();
+            static std::string getExternalDataPathString();
             //! Returns the path to the config files as std::string
             static std::string getConfigPathString();
Index: code/branches/resource2/src/core/GUIManager.cc
===================================================================
--- code/branches/resource2/src/core/GUIManager.cc	(revision 5641)
+++ code/branches/resource2/src/core/GUIManager.cc	(revision 5645)
@@ -171,5 +171,5 @@
     {
         // set datapath for GUI data
-        lua_pushfstring(this->scriptModule_->getLuaState(), Core::getMediaPathString().c_str());
+        lua_pushfstring(this->scriptModule_->getLuaState(), Core::getDataPathString().c_str());
         lua_setglobal(this->scriptModule_->getLuaState(), "datapath");
         // call main Lua script
Index: code/branches/resource2/src/core/LuaBind.cc
===================================================================
--- code/branches/resource2/src/core/LuaBind.cc	(revision 5641)
+++ code/branches/resource2/src/core/LuaBind.cc	(revision 5645)
@@ -47,5 +47,5 @@
   LuaBind::LuaBind()
   {
-    this->includePath_ = Core::getMediaPathString();
+    this->includePath_ = Core::getDataPathString();
 
     luaState_ = lua_open();

Index: code/branches/resource2/src/core/ConfigFileManager.cc
===================================================================
--- code/branches/resource2/src/core/ConfigFileManager.cc	(revision 5641)
+++ code/branches/resource2/src/core/ConfigFileManager.cc	(revision 5645)
@@ -229,6 +229,6 @@
         if (!boost::filesystem::exists(filepath))
         {
-            // Try to get default one from the media folder
-            boost::filesystem::path defaultFilepath(Core::getMediaPath() / "defaultConfig" / this->filename_);
+            // Try to get default one from the data folder
+            boost::filesystem::path defaultFilepath(Core::getDataPath() / "defaultConfig" / this->filename_);
             if (boost::filesystem::exists(defaultFilepath))
             {
Index: code/branches/resource2/src/core/Core.cc
===================================================================
--- code/branches/resource2/src/core/Core.cc	(revision 5641)
+++ code/branches/resource2/src/core/Core.cc	(revision 5645)
@@ -85,5 +85,5 @@
     Core* Core::singletonPtr_s  = 0;
 
-    SetCommandLineArgument(externalMediaPath, "").information("Path to the external media files");
+    SetCommandLineArgument(externalDataPath, "").information("Path to the external data files");
     SetCommandLineOnlyArgument(writingPathSuffix, "").information("Additional subfolder for config and log files");
     SetCommandLineArgument(settingsFile, "orxonox.ini").information("THE configuration file");
@@ -110,10 +110,10 @@
             this->setConfigValues();
 
             // External media directory only exists for dev runs
             if (Core::isDevelopmentRun())
             {
-                // Possible media path override by the command line
-                if (!CommandLine::getArgument("externalMediaPath")->hasDefaultValue())
-                    tsetExternalMediaPath(CommandLine::getValue("externalMediaPath"));
+                // Possible data path override by the command line
+                if (!CommandLine::getArgument("externalDataPath")->hasDefaultValue())
+                    tsetExternalDataPath(CommandLine::getValue("externalDataPath"));
             }
         }
@@ -188,11 +188,11 @@
         /**
         @brief
-            Temporary sets the media path
+            Temporary sets the data path
         @param path
-            The new media path
+            The new data path
         */
-        void tsetExternalMediaPath(const std::string& path)
-        {
-            mediaPath_ = boost::filesystem::path(path);
+        void tsetExternalDataPath(const std::string& path)
+        {
+            dataPath_ = boost::filesystem::path(path);
         }
 
@@ -218,6 +218,6 @@
         boost::filesystem::path rootPath_;
         boost::filesystem::path executablePath_;        //!< Path to the executable
-        boost::filesystem::path mediaPath_;             //!< Path to the media file folder
-        boost::filesystem::path externalMediaPath_;     //!< Path to the media file folder
+        boost::filesystem::path dataPath_;              //!< Path to the data file folder
+        boost::filesystem::path externalDataPath_;      //!< Path to the external data file folder
         boost::filesystem::path configPath_;            //!< Path to the config file folder
         boost::filesystem::path logPath_;               //!< Path to the log file folder
@@ -283,5 +283,5 @@
 
         // initialise Tcl
-        this->tclBind_.reset(new TclBind(Core::getMediaPathString()));
+        this->tclBind_.reset(new TclBind(Core::getDataPathString()));
         this->tclThreadManager_.reset(new TclThreadManager(tclBind_->getTclInterpreter()));
 
@@ -401,25 +401,25 @@
     }
 
-    /*static*/ void Core::tsetExternalMediaPath(const std::string& path)
-    {
-        getInstance().configuration_->tsetExternalMediaPath(path);
-    }
-
-    /*static*/ const boost::filesystem::path& Core::getMediaPath()
-    {
-        return getInstance().configuration_->mediaPath_;
-    }
-    /*static*/ std::string Core::getMediaPathString()
-    {
-        return getInstance().configuration_->mediaPath_.string() + '/';
-    }
-
-    /*static*/ const boost::filesystem::path& Core::getExternalMediaPath()
-    {
-        return getInstance().configuration_->externalMediaPath_;
-    }
-    /*static*/ std::string Core::getExternalMediaPathString()
-    {
-        return getInstance().configuration_->externalMediaPath_.string() + '/';
+    /*static*/ void Core::tsetExternalDataPath(const std::string& path)
+    {
+        getInstance().configuration_->tsetExternalDataPath(path);
+    }
+
+    /*static*/ const boost::filesystem::path& Core::getDataPath()
+    {
+        return getInstance().configuration_->dataPath_;
+    }
+    /*static*/ std::string Core::getDataPathString()
+    {
+        return getInstance().configuration_->dataPath_.string() + '/';
+    }
+
+    /*static*/ const boost::filesystem::path& Core::getExternalDataPath()
+    {
+        return getInstance().configuration_->externalDataPath_;
+    }
+    /*static*/ std::string Core::getExternalDataPathString()
+    {
+        return getInstance().configuration_->externalDataPath_.string() + '/';
     }
 
@@ -561,6 +561,6 @@
             COUT(1) << "Running from the build tree." << std::endl;
             Core::bDevRun_ = true;
-            configuration_->mediaPath_  = specialConfig::mediaDevDirectory;
-            configuration_->externalMediaPath_ = specialConfig::externalMediaDevDirectory;
+            configuration_->dataPath_  = specialConfig::dataDevDirectory;
+            configuration_->externalDataPath_ = specialConfig::externalDataDevDirectory;
             configuration_->configPath_ = specialConfig::configDevDirectory;
             configuration_->logPath_    = specialConfig::logDevDirectory;
@@ -579,5 +579,5 @@
 
             // Using paths relative to the install prefix, complete them
-            configuration_->mediaPath_  = configuration_->rootPath_ / specialConfig::defaultMediaPath;
+            configuration_->dataPath_  = configuration_->rootPath_ / specialConfig::defaultDataPath;
             configuration_->configPath_ = configuration_->rootPath_ / specialConfig::defaultConfigPath;
             configuration_->logPath_    = configuration_->rootPath_ / specialConfig::defaultLogPath;
@@ -585,5 +585,5 @@
             // There is no root path, so don't set it at all
 
-            configuration_->mediaPath_  = specialConfig::mediaInstallDirectory;
+            configuration_->dataPath_  = specialConfig::dataInstallDirectory;
 
             // Get user directory
@@ -110,10 +110,10 @@
             this->setConfigValues();
 
-            // External media directory only exists for dev runs
+            // External data directory only exists for dev runs
             if (Core::isDevelopmentRun())
             {